@@ -41,13 +41,13 @@ import time
 from types import TracebackType  # noqa F401
 from typing import Optional, Type  # noqa F401
 
-from PIL import Image
-
 import selenium.common.exceptions as selenium_exceptions
-import univention.testing.ucr as ucr_test
-import univention.testing.utils as utils
+from PIL import Image
 from selenium import webdriver
 from selenium.webdriver.support import expected_conditions
+
+import univention.testing.ucr as ucr_test
+import univention.testing.utils as utils
 from univention.admin import localization
 from univention.config_registry import handler_set
 from univention.testing.selenium.checks_and_waits import ChecksAndWaits
@@ -104,7 +104,7 @@ class UMCSeleniumTest(ChecksAndWaits, Interactions):
 				chrome_options = webdriver.ChromeOptions()
 				chrome_options.add_argument('--no-sandbox')  # chrome complains about being executed as root
 				chrome_options.add_argument('ignore-certificate-errors')
-				self.driver = webdriver.Chrome(chrome_options=chrome_options)
+				self.driver = webdriver.Chrome(options=chrome_options)
 			else:
 				self.driver = webdriver.Firefox()
 
@@ -171,9 +171,9 @@ class UMCSeleniumTest(ChecksAndWaits, Interactions):
 			timestamp = '_%s' % (datetime.datetime.now().strftime("%Y%m%d%H%M%S"),)
 
 		filename = '%s/%s_%s%s.png' % (self.screenshot_path, name, self.language, timestamp)
-		logger.info('Saving screenshot %r', filename)
+		logger.warning('Saving screenshot %r', filename)
 		if os.environ.get('JENKINS_WS'):
-			logger.info('Screenshot URL: %sws/test/selenium/selenium/%s' % (os.environ['JENKINS_WS'], os.path.basename(filename)))
+			logger.warning('Screenshot URL: %sws/test/selenium/selenium/%s' % (os.environ['JENKINS_WS'], os.path.basename(filename)))
 
 		self.driver.save_screenshot(filename)
 		screenshot = self.crop_screenshot_to_element(filename, xpath)
