@@ -167,10 +167,10 @@ def retry_on_error(func, exceptions=(Exception,), retry_count=20, delay=10):
 		except exceptions:
 			exc_info = sys.exc_info()
 			if i != retry_count:
-				print('Exception occurred: %s (%s). Retrying in %.2f seconds (retry %d/%d).' % (exc_info[0], exc_info[1], delay, i, retry_count))
+				print('Exception occurred: %s (%s). Retrying in %.2f seconds (retry %d/%d).\n' % (exc_info[0], exc_info[1], delay, i, retry_count))
 				time.sleep(delay)
 			else:
-				print('Exception occurred: %s (%s). This was the last retry (retry %d/%d).' % (exc_info[0], exc_info[1], i, retry_count))
+				print('Exception occurred: %s (%s). This was the last retry (retry %d/%d).\n' % (exc_info[0], exc_info[1], i, retry_count))
 	else:
 		six.reraise(*exc_info)
 
@@ -259,20 +259,16 @@ def __verify_ldap_object(baseDn, expected_attr=None, strict=True, should_exist=T
 			if difference:
 				unexpected_values[attribute] = difference
 
-	msg = u'DN: %s\n%s\n%s' % (
+	mixed = dict((key, (values_missing.get(key), unexpected_values.get(key))) for key in list(values_missing) + list(unexpected_values))
+	msg = u'DN: %s\n%s\n' % (
 		baseDn,
 		u'\n'.join(
-			u"%s: %r, missing   : '%s'" % (
+			u"%s: %r, %s %s" % (
 				attribute,
 				attr.get(attribute),
-				u"', ".join(x.decode('UTF-8', 'replace') for x in difference)
-			) for attribute, difference in values_missing.items()),
-		u'\n'.join(
-			u"%s: %r, unexpected: '%s'" % (
-				attribute,
-				attr.get(attribute),
-				u"', ".join(x.decode('UTF-8', 'replace') for x in difference)
-			) for attribute, difference in unexpected_values.items()),
+				('missing: %r;' % u"', ".join(x.decode('UTF-8', 'replace') for x in difference_missing)) if difference_missing else '',
+				('unexpected: %r' % u"', ".join(x.decode('UTF-8', 'replace') for x in difference_unexpected)) if difference_unexpected else '',
+			) for attribute, (difference_missing, difference_unexpected) in mixed.items())
 	)
 
 	if values_missing:
@@ -359,7 +355,7 @@ class AutomaticListenerRestart(object):
 	        with ucr_test.UCSTestConfigRegistry() as ucr:
 	            # set some ucr variables, that influence the Univention Directory Listener
 	            univention.config_registry.handler_set(['foo/bar=ding/dong'])
-	"""
+	"""  # noqa: E101
 
 	def __enter__(self):
 		# type: () -> AutomaticListenerRestart
@@ -391,7 +387,7 @@ class AutoCallCommand(object):
 	            exit_cmd=['/etc/init.d/dovecot', 'restart'],
 	            stderr=open('/dev/zero', 'w')) as acc:
 	        pass
-	"""
+	"""  # noqa: E101
 
 	def __init__(self, enter_cmd=None, exit_cmd=None, stdout=None, stderr=None):
 		# type: (Optional[Sequence[str]], Optional[Sequence[str]], IO[str], IO[str]) -> None
@@ -433,7 +429,7 @@ class FollowLogfile(object):
 	    with FollowLogfile(logfiles=['/var/log/syslog'], always=True):
 	        with utils.AutoCallCommand(enter_cmd=cmd, exit_cmd=cmd):
 	            pass
-	"""
+	"""  # noqa: E101
 
 	def __init__(self, logfiles, always=False):
 		# type: (Iterable[str], bool) -> None
